@@ -13,4 +13,4 @@
 ( cd opt/kde/share/doc/HTML/en/kteatime ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kteatime ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/apps/amor ; rm -rf tips )
-( cd opt/kde/share/apps/amor ; ln -sf /root/kde-3.1.2/kdetoys/temp/opt/kde/share/apps/amor/tips-en tips )
+( cd opt/kde/share/apps/amor ; ln -sf /opt/kde/share/apps/amor/tips-en tips )
